summaryrefslogtreecommitdiff
path: root/protocols/Twitter/src/proto.cpp
diff options
context:
space:
mode:
authordartraiden <wowemuh@gmail.com>2019-06-04 15:50:53 +0300
committerdartraiden <wowemuh@gmail.com>2019-06-04 15:51:36 +0300
commit49e2ce57910d52c914af340bd14e6970b734a922 (patch)
treebc2db35f25b62d6287315fefe5a273a46253e12d /protocols/Twitter/src/proto.cpp
parent069b1736634b81fbd99909f668f4318fab4cc9b9 (diff)
fix fo statuses ids
Diffstat (limited to 'protocols/Twitter/src/proto.cpp')
-rw-r--r--protocols/Twitter/src/proto.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/protocols/Twitter/src/proto.cpp b/protocols/Twitter/src/proto.cpp
index 3a1b07cc2e..7db3a47156 100644
--- a/protocols/Twitter/src/proto.cpp
+++ b/protocols/Twitter/src/proto.cpp
@@ -172,8 +172,8 @@ int TwitterProto::SetStatus(int new_status)
return 0;
m_iDesiredStatus = new_status;
- // 40072 - 40080 are the "online" statuses, basically every status except offline. see statusmodes.h
- if (new_status >= 40072 && new_status <= 40080) {
+ // 40072 - 40077 are the "online" statuses, basically every status except offline. see statusmodes.h
+ if (new_status >= 40072 && new_status <= 40077) {
m_iDesiredStatus = ID_STATUS_ONLINE; //i think i have to set this so it forces the twitter proto to be online (and not away, DND, etc)
@@ -182,7 +182,7 @@ int TwitterProto::SetStatus(int new_status)
return 0;
// if we're already connected, and we change to another connected status, don't try and reconnect!
- if (old_status >= 40072 && old_status <= 40080)
+ if (old_status >= 40072 && old_status <= 40077)
return 0;
// i think here we tell the proto interface struct that we're connecting, just so it knows